package main

import (
	"flag"

	"time"

	"os"

	"github.com/8thlight/vulcanizedb/cmd"
	"github.com/8thlight/vulcanizedb/pkg/core"
	"github.com/8thlight/vulcanizedb/pkg/geth"
	"github.com/8thlight/vulcanizedb/pkg/history"
	"github.com/8thlight/vulcanizedb/pkg/repositories"
)

const (
	pollingInterval = 7 * time.Second
)

func backFillAllBlocks(blockchain core.Blockchain, repository repositories.Postgres, missingBlocksPopulated chan int) {
	go func() {
		missingBlocksPopulated <- history.PopulateMissingBlocks(blockchain, repository, 0)
	}()
}

func main() {
	environment := flag.String("environment", "", "Environment name")
	flag.Parse()

	ticker := time.NewTicker(pollingInterval)
	defer ticker.Stop()

	config := cmd.LoadConfig(*environment)
	blockchain := geth.NewBlockchain(config.Client.IPCPath)
	repository := cmd.LoadPostgres(config.Database, blockchain.Node())
	validator := history.NewBlockValidator(blockchain, repository, 15)

	missingBlocksPopulated := make(chan int)
	go backFillAllBlocks(blockchain, repository, missingBlocksPopulated)

	for {
		select {
		case <-ticker.C:
			window := validator.ValidateBlocks()
			validator.Log(os.Stdout, window)
		case <-missingBlocksPopulated:
			go backFillAllBlocks(blockchain, repository, missingBlocksPopulated)
		}
	}
}
